@@ -15,10 +15,12 @@ to do next after a job completes
 """
 
 from collections import defaultdict, OrderedDict
-import copy
+import re
+import abc
 
 import datetime
 import os
+import pprint
 from fireworks.core.fw_config import FWConfig
 from fireworks.core.fworker import FWorker
 from fireworks.utilities.dict_mods import apply_mod
@@ -27,6 +29,7 @@ from fireworks.utilities.fw_serializers import FWSerializable, \
 from fireworks.utilities.fw_utilities import get_my_host, get_my_ip, NestedClassGetter, reverse_readline
 
 __author__ = "Anubhav Jain"
+__credits__ = "Shyue Ping Ong"
 __copyright__ = "Copyright 2013, The Materials Project"
 __version__ = "0.1"
 __maintainer__ = "Anubhav Jain"
@@ -34,26 +37,53 @@ __email__ = "ajain@lbl.gov"
 __date__ = "Feb 5, 2013"
 
 
+class FireTaskMeta(type):
+
+    __metaclass__ = abc.ABCMeta
+
+    def __init__(cls, name, bases, dct):
+        # Set default _fw_name to be a space separated version of the class
+        # name.
+        if name != "FireTaskBase" and not hasattr(cls, "_fw_name"):
+            cls._fw_name = name
+        type.__init__(cls, name, bases, dct)
+
+    def __call__(cls, *args, **kwargs):
+        o = type.__call__(cls, *args, **kwargs)
+        for k in cls.required_params:
+            if k not in o:
+                raise ValueError("Required parameter {} not specified!"
+                                 .format(k))
+        return o
+
+
 class FireTaskBase(dict, FWSerializable):
     """
     FireTaskBase is used like an abstract class that defines a computing task
-     (FireTask). All FireTasks
-    should inherit from FireTaskBase.
+    (FireTask). All FireTasks should inherit from FireTaskBase.
 
     You can set parameters of a FireTask like you'd use a dict.
     """
+    __metaclass__ = FireTaskMeta
 
+    # Specify required parameters with class variable. Consistency will be
+    # checked upon init.
+    required_params = []
+
+    def __init__(self, *args, **kwargs):
+        dict.__init__(self, *args, **kwargs)
+
+    @abc.abstractmethod
     def run_task(self, fw_spec):
         """
         This method gets called when the FireTask is run. It can take in a
-        FireWork spec,
-        perform some task using that data, and then return an output in the
-        form of a FWAction.
+        FireWork spec, perform some task using that data, and then return an
+        output in the form of a FWAction.
 
         :param fw_spec: (dict) a FireWork spec
         :return: (FWAction)
         """
-        raise NotImplementedError('The FireTask needs to implement run_task()!')
+        pass
 
     @serialize_fw
     @recursive_serialize
@@ -142,6 +172,9 @@ class FWAction(FWSerializable):
         """
         return self.exit or self.detours or self.additions or self.defuse_children
 
+    def __str__(self):
+        return "FWAction\n" + pprint.pformat(self.to_dict())
+
 
 class FireWork(FWSerializable):
     """
@@ -891,4 +924,4 @@ class Workflow(FWSerializable):
         return Workflow([fw], None, name=name, metadata=metadata)
 
     def __str__(self):
-        return 'Workflow object: (fw_ids: {} , name: {})'.format(self.id_fw.keys(), self.name)
\ No newline at end of file
+        return 'Workflow object: (fw_ids: {} , name: {})'.format(self.id_fw.keys(), self.name)
