@@ -33,7 +33,7 @@ class FWConfig(object):
         self.USER_PACKAGES = ['fireworks.user_objects', 'fireworks.utilities.tests',
                               'fw_tutorials']  # this is where load_object() looks for serialized objects
 
-        self.FW_NAME_UPDATES = {}  # if you update a _fw_name, you can use this to record the change and maintain
+        self.FW_NAME_UPDATES = {'Transfer Task': 'FileTransferTask', 'Script Task': 'ScriptTask', 'Template Writer Task':'TemplateWriterTask'}  # if you update a _fw_name, you can use this to record the change and maintain
         # deserialization
 
         self.YAML_STYLE = False  # controls whether YAML documents will be nested as braces or blocks (False = blocks)
@@ -82,20 +82,30 @@ class FWConfig(object):
 
         self.TRACKER_LINES = 25  # number of lines to return in Tracker
 
+        self.SORT_FWS = ''  # sort equal priority FWs? "FILO" or "FIFO".
+
         self.override_user_settings()
 
     def override_user_settings(self):
-        if "FW_CONFIG_FILE" in os.environ:
-            config_path = os.environ['FW_CONFIG_FILE']
 
-        elif os.path.exists(os.path.join(os.getcwd(), 'FW_config.yaml')):
+        MODULE_DIR = os.path.dirname(os.path.abspath(__file__))
+        root_dir = os.path.dirname(os.path.dirname(MODULE_DIR))  # FW root dir
+
+        if os.path.exists(os.path.join(os.getcwd(), 'FW_config.yaml')):
             config_path=os.path.join(os.getcwd(), 'FW_config.yaml')
 
-        else:
-            MODULE_DIR = os.path.dirname(os.path.abspath(__file__))
-            root_dir = os.path.dirname(os.path.dirname(MODULE_DIR))
-            config_path = os.path.join(root_dir, 'FW_config.yaml')
+        elif "FW_CONFIG_FILE" in os.environ:
+            config_path = os.environ['FW_CONFIG_FILE']
 
+        elif os.path.exists(os.path.join(root_dir, 'FW_config.yaml')):
+            config_path=os.path.join(root_dir, 'FW_config.yaml')
+
+        else:
+            config_path = os.path.join(os.environ["HOME"], ".fireworks",
+                                       'FW_config.yaml')
+        # else:
+        #     #Is there even an FW_config here????
+        #
         if os.path.exists(config_path):
             with open(config_path) as f:
                 overrides = yaml.load(f.read())
@@ -111,6 +121,12 @@ class FWConfig(object):
                     else:
                         self.__setattr__(key, v)
 
+    def to_dict(self):
+        d = {}
+        for k, v in self.__dict__.items():
+            d[k] = v
+        return d
+
 
 @singleton
 class FWData(object):
@@ -120,7 +136,6 @@ class FWData(object):
 
     def __init__(self):
         self.MULTIPROCESSING = None # default single process framework
-        self.PROCESS_LOCK = None  # the shared Lock between processes
         self.NODE_LIST = None  # the node list for sub jobs
         self.SUB_NPROCS = None  # the number of process of the sub job
         self.DATASERVER = None  # the shared object manager
\ No newline at end of file
