@@ -17,20 +17,22 @@ __date__ = 'Aug 08, 2013'
 
 
 class TemplateWriterTask(FireTaskBase, FWSerializable):
-    _fw_name = "Template Writer Task"
-
-    def __init__(self, parameters):
-        """
-        :param parameters: (dict) parameters. Required are "template_file" (str), "context" (dict), and "output_file" (str). Optional are "append" (T/F) and "template_dir" (str).
-        """
-        self.update(parameters)
-
-        if not parameters.get("use_global_spec"):
-            self._load_parameters(parameters)
+    """
+    Task to write templated files via Jinja2 library
+    Required parameters:
+        - template_file: (str) - path to template file
+        - context: (dict) - variable replacements for the template file
+        - output_file: (str) - output file
+    Optional parameters:
+        - append: (bool) - append to output file (instead of overwrite)
+        - template_dir: (str) - directory in which to find the template file
+    """
 
     def run_task(self, fw_spec):
         if self.get("use_global_spec"):
-            self._load_parameters(fw_spec)
+            self._load_params(fw_spec)
+        else:
+            self._load_params(self)
 
         with open(self.template_file) as f:
             t = Template(f.read())
@@ -40,20 +42,20 @@ class TemplateWriterTask(FireTaskBase, FWSerializable):
             with open(self.output_file, write_mode) as of:
                 of.write(output)
 
-    def _load_parameters(self, params):
+    def _load_params(self, d):
 
-        self.context = params['context']
-        self.output_file = params['output_file']
-        self.append_file = params.get('append')  # append to output file?
+        self.context = d['context']
+        self.output_file = d['output_file']
+        self.append_file = d.get('append')  # append to output file?
 
-        if params.get('template_dir'):
-            self.template_dir = params['template_dir']
+        if d.get('template_dir'):
+            self.template_dir = d['template_dir']
         elif FWConfig().TEMPLATE_DIR:
             self.template_dir = FWConfig().TEMPLATE_DIR
         else:
             MODULE_DIR = os.path.dirname(os.path.abspath(__file__))
             self.template_dir = os.path.join(MODULE_DIR, 'templates')
 
-        self.template_file = os.path.join(self.template_dir, params['template_file'])
+        self.template_file = os.path.join(self.template_dir, d['template_file'])
         if not os.path.exists(self.template_file):
-            raise ValueError("Template Writer Task could not find a template file at: {}".format(self.template_file))
\ No newline at end of file
+            raise ValueError("TemplateWriterTask could not find a template file at: {}".format(self.template_file))
\ No newline at end of file
